@@ -3,7 +3,7 @@
      /***************************************************
       *  Disk Quota Plugin                              *
       *  By Kerem Erkan <kerem.erkan@hacettepe.edu.tr>  *
-      *  Version 3.0.2                                  *
+      *  Version 3.0.3                                  *
       *  See INSTALL for usage details.                 *
       ***************************************************/
 
@@ -27,6 +27,13 @@ $dq_click = 0;
 
 putenv("LANG=C");
 
+if ( phpversion() >= "4.2.0" && $dq_check_on_remote == 1 ) {
+
+    extract($_POST);
+    extract($_GET);
+
+}
+
 if ( $dq_check_on_remote == 1 ) {
 
     $dq_quota_binary = str_replace("_", " ", $dq_quota_binary);
